@@ -38,6 +38,7 @@ public:
 
 protected:
     QSize sizeHint() const override;
+    bool event(QEvent *e) override;
 
 private Q_SLOTS:
     void initApplication();
@@ -66,6 +67,7 @@ private:
     // The toolbar
     QWidgetAction *spacerAction = nullptr;
     QAction *highlightChangesAction = nullptr;
+    QAction *showIrrelevantAction = nullptr;
     QAction *reportPageSpecificBugAction = nullptr;
     QAction *quitAction = nullptr;
     // The help menu
